#ifndef WATCH_DIR_H
#  define WATCH_DIR_H

/* vim: cin ts=8 sw=4 syn=c
 *
 * $Id$
 *
 * Copyright (c) 2007 Garry T. Williams */

static void handle_event(struct inotify_event *event, int ev_cnt, int cnt);
static void catch_sig(int signo);

/*

=pod

=head1 NAME

watch_dir - demo of inotify

=head1 SYNOPSIS

B<watch_dir> I<dir-name>

=head1 DESCRIPTION

This program will print inotify events to stdout for events in
I<dir-name>.  To stop execution, hit CTRL-C.

watch_dir calls poll(2) to wait for events on the inotify file
descriptor.  When poll() returns, fcntl() is called to get the number
of bytes that can be read from the inotify descriptor.  A read(2) is
made to get this number of bytes and it is assumed that this will be
an integral number of inotify events.  Each event will be logged with
the count of blocks read and the event count within a block.  This
information makes it possible to get a feel for the size of blocks
that will be presented by the inotify API.

During testing with valgrind, I observed a maximum block size of
18,272 bytes which included 315 events.  This indicates that a correct
implementation of a program using the inotify API should either read a
fixed block size and handle the the case where read(2) returns a
partial event or be prepared to read arbitrarily large blocks.  This
implementation uses the latter technique -- we realloc() our buffer
based on the return from fcntl().

=head1 EXIT STATUS

This program will exit with a status of 1, if an error is encountered.

=head1 SEE ALSO

inotify(7), read(2), L<http://valgrind.org/>

=head1 COPYRIGHT

Copyright (c) 2007 Garry T. Williams

=head1 AUTHOR

Garry T. Williams E<lt>gtwilliams@gmail.comE<gt>

=cut

 */

#endif
